pub struct ItemNumbers {
pub slot_number: u64,
pub batch_number: u64,
pub tx_number: u64,
pub event_number: u64,
}Expand description
A SlotNumber, BatchNumber, TxNumber, and EventNumber which are grouped together, typically representing the respective heights at the start or end of slot processing.
Fields
slot_number: u64The slot number
batch_number: u64The batch number
tx_number: u64The transaction number
event_number: u64The event number