pub struct DbBytes(/* private fields */);Expand description
A cheaply cloneable bytes abstraction for use within the trust boundary of the node (i.e. when interfacing with the database). Serializes and deserializes more efficiently, than most bytes abstractions, but is vulnerable to out-of-memory attacks when read from an untrusted source.
Warning
Do not use this type when deserializing data from an untrusted source!!
Implementations