pub struct SlotNumber(pub u64);Expand description
A typed wrapper around u64 implementing Encode and Decode
Tuple Fields
0: u64Trait Implementations
Sourceimpl BorshDeserialize for SlotNumber
impl BorshDeserialize for SlotNumber
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SlotNumber
impl BorshSerialize for SlotNumber
Sourceimpl Clone for SlotNumber
impl Clone for SlotNumber
Sourcefn clone(&self) -> SlotNumber
fn clone(&self) -> SlotNumber
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SlotNumber
Sourceimpl Debug for SlotNumber
impl Debug for SlotNumber
Sourceimpl Default for SlotNumber
impl Default for SlotNumber
Sourcefn default() -> SlotNumber
fn default() -> SlotNumber
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SlotNumber
impl<'de> Deserialize<'de> for SlotNumber
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SlotNumber
Sourceimpl From<SlotNumber> for u64
impl From<SlotNumber> for u64
Sourcefn from(value: SlotNumber) -> Self
fn from(value: SlotNumber) -> Self
Converts to this type from the input type.
Sourceimpl Ord for SlotNumber
impl Ord for SlotNumber
Sourcefn cmp(&self, other: &SlotNumber) -> Ordering
fn cmp(&self, other: &SlotNumber) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SlotNumber
impl PartialEq for SlotNumber
Sourcefn eq(&self, other: &SlotNumber) -> bool
fn eq(&self, other: &SlotNumber) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SlotNumber
impl PartialOrd for SlotNumber
Sourceimpl Serialize for SlotNumber
impl Serialize for SlotNumber
impl StructuralPartialEq for SlotNumber