pub struct StoredBatch {
pub hash: DbHash,
pub txs: Range<TxNumber>,
pub custom_receipt: DbBytes,
}Expand description
The on-disk format for a batch. Stores the hash and identifies the range of transactions included in the batch.
Fields
hash: DbHashThe hash of the batch, as reported by the DA layer.
txs: Range<TxNumber>The range of transactions which occurred in this batch.
custom_receipt: DbBytesA customer “receipt” for this batch defined by the rollup.