pub struct TxNumber(pub u64);Expand description
A typed wrapper around u64 implementing Encode and Decode
Tuple Fields
0: u64Trait Implementations
Sourceimpl BorshDeserialize for TxNumber
impl BorshDeserialize for TxNumber
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TxNumber
impl BorshSerialize for TxNumber
impl Copy for TxNumber
Sourceimpl<'de> Deserialize<'de> for TxNumber
impl<'de> Deserialize<'de> for TxNumber
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TxNumber
Sourceimpl Ord for TxNumber
impl Ord for TxNumber
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for TxNumber
impl PartialOrd for TxNumber
impl StructuralPartialEq for TxNumber